==> drei-10.1.2.tgz: package/core/index.js <==
export { Billboard } from './Billboard.js';
export { ScreenSpace } from './ScreenSpace.js';
export { ScreenSizer } from './ScreenSizer.js';
export { QuadraticBezierLine } from './QuadraticBezierLine.js';
export { CubicBezierLine } from './CubicBezierLine.js';
export { CatmullRomLine } from './CatmullRomLine.js';
export { Line } from './Line.js';
export { PositionalAudio } from './PositionalAudio.js';
export { Text } from './Text.js';
export { Text3D } from './Text3D.js';
export { Effects, isWebGL2Available } from './Effects.js';
export { GradientTexture, GradientType } from './GradientTexture.js';
export { Image } from './Image.js';
export { Edges } from './Edges.js';
export { Outlines } from './Outlines.js';
export { Trail, useTrail } from './Trail.js';
export { Sampler, useSurfaceSampler } from './Sampler.js';
export { ComputedAttribute } from './ComputedAttribute.js';
export { Clone } from './Clone.js';
export { MarchingCube, MarchingCubes, MarchingPlane } from './MarchingCubes.js';
export { Decal } from './Decal.js';
export { Svg } from './Svg.js';
export { Gltf, useGLTF } from './Gltf.js';
export { AsciiRenderer } from './AsciiRenderer.js';
export { Splat } from './Splat.js';
export { OrthographicCamera } from './OrthographicCamera.js';
export { PerspectiveCamera } from './PerspectiveCamera.js';
export { CubeCamera, useCubeCamera } from './CubeCamera.js';
export { DeviceOrientationControls } from './DeviceOrientationControls.js';
export { FlyControls } from './FlyControls.js';
export { MapControls } from './MapControls.js';
export { OrbitControls } from './OrbitControls.js';
export { TrackballControls } from './TrackballControls.js';
export { ArcballControls } from './ArcballControls.js';
export { TransformControls } from './TransformControls.js';
export { PointerLockControls } from './PointerLockControls.js';
export { FirstPersonControls } from './FirstPersonControls.js';
export { CameraControls } from './CameraControls.js';
export { MotionPathControls, useMotion } from './MotionPathControls.js';
export { GizmoHelper, useGizmoContext } from './GizmoHelper.js';
export { GizmoViewcube } from './GizmoViewcube.js';
export { GizmoViewport } from './GizmoViewport.js';
export { Grid } from './Grid.js';
export { CubeTexture, useCubeTexture } from './CubeTexture.js';
export { Fbx, useFBX } from './Fbx.js';
export { Ktx2, useKTX2 } from './Ktx2.js';
export { Progress, useProgress } from './Progress.js';
export { IsObject, Texture, useTexture } from './Texture.js';
export { VideoTexture, useVideoTexture } from './VideoTexture.js';
export { useFont } from './useFont.js';
export { checkIfFrameIsEmpty, getFirstFrame, useSpriteLoader } from './useSpriteLoader.js';
export { Helper, useHelper } from './Helper.js';
export { Stats } from './Stats.js';
export { StatsGl } from './StatsGl.js';
export { useDepthBuffer } from './useDepthBuffer.js';
export { useAspect } from './useAspect.js';
export { useCamera } from './useCamera.js';
export { DetectGPU, useDetectGPU } from './DetectGPU.js';
export { Bvh, useBVH } from './Bvh.js';
export { useContextBridge } from './useContextBridge.js';
export { useAnimations } from './useAnimations.js';
export { Fbo, useFBO } from './Fbo.js';
export { useIntersect } from './useIntersect.js';
export { useBoxProjectedEnv } from './useBoxProjectedEnv.js';
export { BBAnchor } from './BBAnchor.js';
export { TrailTexture, useTrailTexture } from './TrailTexture.js';
export { Example } from './Example.js';
export { SpriteAnimator, useSpriteAnimator } from './SpriteAnimator.js';
export { CurveModifier } from './CurveModifier.js';
export { MeshDistortMaterial } from './MeshDistortMaterial.js';
export { MeshWobbleMaterial } from './MeshWobbleMaterial.js';
export { MeshReflectorMaterial } from './MeshReflectorMaterial.js';
export { MeshRefractionMaterial } from './MeshRefractionMaterial.js';
export { MeshTransmissionMaterial } from './MeshTransmissionMaterial.js';
export { MeshDiscardMaterial } from './MeshDiscardMaterial.js';
export { MultiMaterial } from './MultiMaterial.js';
export { PointMaterial, PointMaterialImpl } from './PointMaterial.js';
export { shaderMaterial } from './shaderMaterial.js';
export { SoftShadows } from './softShadows.js';
export { Box, Capsule, Circle, Cone, Cylinder, Dodecahedron, Extrude, Icosahedron, Lathe, Octahedron, Plane, Polyhedron, Ring, Shape, Sphere, Tetrahedron, Torus, TorusKnot, Tube } from './shapes.js';
export { RoundedBox } from './RoundedBox.js';
export { ScreenQuad } from './ScreenQuad.js';
export { Center } from './Center.js';
export { Resize } from './Resize.js';
export { Bounds, useBounds } from './Bounds.js';
export { CameraShake } from './CameraShake.js';
export { Float } from './Float.js';
export { Stage } from './Stage.js';
export { Backdrop } from './Backdrop.js';
export { Shadow } from './Shadow.js';
export { Caustics } from './Caustics.js';
export { ContactShadows } from './ContactShadows.js';
export { AccumulativeShadows, RandomizedLight, accumulativeContext } from './AccumulativeShadows.js';
export { SpotLight, SpotLightShadow } from './SpotLight.js';
export { Environment, EnvironmentCube, EnvironmentMap, EnvironmentPortal } from './Environment.js';
export { Lightformer } from './Lightformer.js';
export { Sky, calcPosFromAngles } from './Sky.js';
export { Stars } from './Stars.js';
export { Cloud, CloudInstance, Clouds } from './Cloud.js';
export { Sparkles } from './Sparkles.js';
export { useEnvironment } from './useEnvironment.js';
export { MatcapTexture, useMatcapTexture } from './MatcapTexture.js';
export { NormalTexture, useNormalTexture } from './NormalTexture.js';
export { Wireframe } from './Wireframe.js';
export { ShadowAlpha } from './ShadowAlpha.js';
export { Point, Points, PointsBuffer, PositionPoint } from './Points.js';
export { Instance, InstancedAttribute, Instances, Merged, PositionMesh, createInstances } from './Instances.js';
export { Segment, SegmentObject, Segments } from './Segments.js';
export { Detailed } from './Detailed.js';
export { Preload } from './Preload.js';
export { BakeShadows } from './BakeShadows.js';
export { meshBounds } from './meshBounds.js';
export { AdaptiveDpr } from './AdaptiveDpr.js';
export { AdaptiveEvents } from './AdaptiveEvents.js';
export { PerformanceMonitor, usePerformanceMonitor } from './PerformanceMonitor.js';
export { RenderTexture } from './RenderTexture.js';
export { RenderCubeTexture } from './RenderCubeTexture.js';
export { Mask, useMask } from './Mask.js';
export { Hud } from './Hud.js';
export { Fisheye } from './Fisheye.js';
export { MeshPortalMaterial } from './MeshPortalMaterial.js';
export { calculateScaleFactor } from './calculateScaleFactor.js';
export { default as CameraControlsImpl } from 'camera-controls';
import '@babel/runtime/helpers/esm/extends';
import 'react';
import 'three';
import '@react-three/fiber';
import 'three-stdlib';
import 'troika-three-text';
import 'suspend-react';
import '../helpers/constants.js';
import 'meshline';
import 'maath';
import 'zustand';
import 'hls.js';
import 'stats.js';
import '../helpers/useEffectfulState.js';
import 'stats-gl';
import 'detect-gpu';
import 'three-mesh-bvh';
import '../helpers/deprecated.js';
import '../materials/BlurPass.js';
import '../materials/ConvolutionMaterial.js';
import '../materials/MeshReflectorMaterial.js';
import '../materials/MeshRefractionMaterial.js';
import '../materials/DiscardMaterial.js';
import '@monogrid/gainmap-js';
import '../helpers/environment-assets.js';
import '../materials/SpotLightMaterial.js';
import '../materials/WireframeMaterial.js';

==> drei-10.2.0.tgz: package/core/index.js <==
export { Billboard } from './Billboard.js';
export { ScreenSpace } from './ScreenSpace.js';
export { ScreenSizer } from './ScreenSizer.js';
export { QuadraticBezierLine } from './QuadraticBezierLine.js';
export { CubicBezierLine } from './CubicBezierLine.js';
export { CatmullRomLine } from './CatmullRomLine.js';
export { Line } from './Line.js';
export { PositionalAudio } from './PositionalAudio.js';
export { Text } from './Text.js';
export { Text3D } from './Text3D.js';
export { Effects, isWebGL2Available } from './Effects.js';
export { GradientTexture, GradientType } from './GradientTexture.js';
export { Image } from './Image.js';
export { Edges } from './Edges.js';
export { Outlines } from './Outlines.js';
export { Trail, useTrail } from './Trail.js';
export { Sampler, useSurfaceSampler } from './Sampler.js';
export { ComputedAttribute } from './ComputedAttribute.js';
export { Clone } from './Clone.js';
export { MarchingCube, MarchingCubes, MarchingPlane } from './MarchingCubes.js';
export { Decal } from './Decal.js';
export { Svg } from './Svg.js';
export { Gltf, useGLTF } from './Gltf.js';
export { AsciiRenderer } from './AsciiRenderer.js';
export { Splat } from './Splat.js';
export { OrthographicCamera } from './OrthographicCamera.js';
export { PerspectiveCamera } from './PerspectiveCamera.js';
export { CubeCamera, useCubeCamera } from './CubeCamera.js';
export { DeviceOrientationControls } from './DeviceOrientationControls.js';
export { FlyControls } from './FlyControls.js';
export { MapControls } from './MapControls.js';
export { OrbitControls } from './OrbitControls.js';
export { TrackballControls } from './TrackballControls.js';
export { ArcballControls } from './ArcballControls.js';
export { TransformControls } from './TransformControls.js';
export { PointerLockControls } from './PointerLockControls.js';
export { FirstPersonControls } from './FirstPersonControls.js';
export { CameraControls } from './CameraControls.js';
export { MotionPathControls, useMotion } from './MotionPathControls.js';
export { GizmoHelper, useGizmoContext } from './GizmoHelper.js';
export { GizmoViewcube } from './GizmoViewcube.js';
export { GizmoViewport } from './GizmoViewport.js';
export { Grid } from './Grid.js';
export { CubeTexture, useCubeTexture } from './CubeTexture.js';
export { Fbx, useFBX } from './Fbx.js';
export { Ktx2, useKTX2 } from './Ktx2.js';
export { Progress, useProgress } from './Progress.js';
export { IsObject, Texture, useTexture } from './Texture.js';
export { VideoTexture, useVideoTexture } from './VideoTexture.js';
export { useFont } from './useFont.js';
export { checkIfFrameIsEmpty, getFirstFrame, useSpriteLoader } from './useSpriteLoader.js';
export { Helper, useHelper } from './Helper.js';
export { Stats } from './Stats.js';
export { StatsGl } from './StatsGl.js';
export { useDepthBuffer } from './useDepthBuffer.js';
export { useAspect } from './useAspect.js';
export { useCamera } from './useCamera.js';
export { DetectGPU, useDetectGPU } from './DetectGPU.js';
export { Bvh, useBVH } from './Bvh.js';
export { useContextBridge } from './useContextBridge.js';
export { useAnimations } from './useAnimations.js';
export { Fbo, useFBO } from './Fbo.js';
export { useIntersect } from './useIntersect.js';
export { useBoxProjectedEnv } from './useBoxProjectedEnv.js';
export { BBAnchor } from './BBAnchor.js';
export { TrailTexture, useTrailTexture } from './TrailTexture.js';
export { Example } from './Example.js';
export { SpriteAnimator, useSpriteAnimator } from './SpriteAnimator.js';
export { CurveModifier } from './CurveModifier.js';
export { MeshDistortMaterial } from './MeshDistortMaterial.js';
export { MeshWobbleMaterial } from './MeshWobbleMaterial.js';
export { MeshReflectorMaterial } from './MeshReflectorMaterial.js';
export { MeshRefractionMaterial } from './MeshRefractionMaterial.js';
export { MeshTransmissionMaterial } from './MeshTransmissionMaterial.js';
export { MeshDiscardMaterial } from './MeshDiscardMaterial.js';
export { MultiMaterial } from './MultiMaterial.js';
export { PointMaterial, PointMaterialImpl } from './PointMaterial.js';
export { shaderMaterial } from './shaderMaterial.js';
export { SoftShadows } from './softShadows.js';
export { Box, Capsule, Circle, Cone, Cylinder, Dodecahedron, Extrude, Icosahedron, Lathe, Octahedron, Plane, Polyhedron, Ring, Shape, Sphere, Tetrahedron, Torus, TorusKnot, Tube } from './shapes.js';
export { RoundedBox, RoundedBoxGeometry } from './RoundedBox.js';
export { ScreenQuad } from './ScreenQuad.js';
export { Center } from './Center.js';
export { Resize } from './Resize.js';
export { Bounds, useBounds } from './Bounds.js';
export { CameraShake } from './CameraShake.js';
export { Float } from './Float.js';
export { Stage } from './Stage.js';
export { Backdrop } from './Backdrop.js';
export { Shadow } from './Shadow.js';
export { Caustics } from './Caustics.js';
export { ContactShadows } from './ContactShadows.js';
export { AccumulativeShadows, RandomizedLight, accumulativeContext } from './AccumulativeShadows.js';
export { SpotLight, SpotLightShadow } from './SpotLight.js';
export { Environment, EnvironmentCube, EnvironmentMap, EnvironmentPortal } from './Environment.js';
export { Lightformer } from './Lightformer.js';
export { Sky, calcPosFromAngles } from './Sky.js';
export { Stars } from './Stars.js';
export { Cloud, CloudInstance, Clouds } from './Cloud.js';
export { Sparkles } from './Sparkles.js';
export { useEnvironment } from './useEnvironment.js';
export { MatcapTexture, useMatcapTexture } from './MatcapTexture.js';
export { NormalTexture, useNormalTexture } from './NormalTexture.js';
export { Wireframe } from './Wireframe.js';
export { ShadowAlpha } from './ShadowAlpha.js';
export { Point, Points, PointsBuffer, PositionPoint } from './Points.js';
export { Instance, InstancedAttribute, Instances, Merged, PositionMesh, createInstances } from './Instances.js';
export { Segment, SegmentObject, Segments } from './Segments.js';
export { Detailed } from './Detailed.js';
export { Preload } from './Preload.js';
export { BakeShadows } from './BakeShadows.js';
export { meshBounds } from './meshBounds.js';
export { AdaptiveDpr } from './AdaptiveDpr.js';
export { AdaptiveEvents } from './AdaptiveEvents.js';
export { PerformanceMonitor, usePerformanceMonitor } from './PerformanceMonitor.js';
export { RenderTexture } from './RenderTexture.js';
export { RenderCubeTexture } from './RenderCubeTexture.js';
export { Mask, useMask } from './Mask.js';
export { Hud } from './Hud.js';
export { Fisheye } from './Fisheye.js';
export { MeshPortalMaterial } from './MeshPortalMaterial.js';
export { calculateScaleFactor } from './calculateScaleFactor.js';
export { default as CameraControlsImpl } from 'camera-controls';
import '@babel/runtime/helpers/esm/extends';
import 'react';
import 'three';
import '@react-three/fiber';
import 'three-stdlib';
import 'troika-three-text';
import 'suspend-react';
import '../helpers/constants.js';
import 'meshline';
import 'maath';
import 'zustand';
import 'hls.js';
import 'stats.js';
import '../helpers/useEffectfulState.js';
import 'stats-gl';
import 'detect-gpu';
import 'three-mesh-bvh';
import '../helpers/deprecated.js';
import '../materials/BlurPass.js';
import '../materials/ConvolutionMaterial.js';
import '../materials/MeshReflectorMaterial.js';
import '../materials/MeshRefractionMaterial.js';
import '../materials/DiscardMaterial.js';
import '@monogrid/gainmap-js';
import '../helpers/environment-assets.js';
import '../materials/SpotLightMaterial.js';
import '../materials/WireframeMaterial.js';
